@@ -1,10 +1,10 @@
-__version__ = "0.2.34"
+__version__ = "0.2.35"
 __git_commiter_name__ = "Arnon Yaari"
 __git_commiter_email__ = "arnony@infinidat.com"
-__git_branch__ = '(detached from v0.2.34)'
+__git_branch__ = '(detached from v0.2.35)'
 __git_remote_tracking_branch__ = '(No remote tracking)'
 __git_remote_url__ = '(Not remote tracking)'
-__git_head_hash__ = '6582e7d7943f6928f2b4b156c20563573dd43f60'
-__git_head_subject__ = 'Finished release v0.2.34.'
+__git_head_hash__ = '8f1826bc3d628afb86779bb453f199b31876fdad'
+__git_head_subject__ = 'HIPVM-603 fix'
 __git_head_message__ = ''
 __git_dirty_diff__ = ''
\ No newline at end of file
