@@ -17,6 +17,7 @@ class StorageModel(object):
     * Multipath
     * Disks
     * Mounts
+    * Utils
 
     All layers are fetched lazily and cached inside the model. When you think that the cache no longer up-to-date,
     you can clear it using the refresh() method
@@ -54,6 +55,11 @@ class StorageModel(object):
         """Returns an instance of `infi.storagemodel.base.mount.MountRepository` """
         return self._create_mount_repository()
 
+    @cached_method
+    def get_utils(self):
+        """Returns an instance of `infi.storagemodel.base.utils.Utils` """
+        return self._create_utils()
+
     def refresh(self):
         """clears the model cache"""
         from ..connectivity import ConnectivityFactory
@@ -141,3 +147,7 @@ class StorageModel(object):
     def _create_mount_repository(self):  # pragma: no cover
         # platform implementation
         raise NotImplementedError()
+
+    def _create_utils(self):  # pragma: no cover
+        # platform implementation
+        raise NotImplementedError()
